<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://brewpixel.com
 * @since             1.0.0
 * @package           BrewPixel_Reviews
 *
 * @wordpress-plugin
 * Plugin Name:       BrewPixel Reviews
 * Plugin URI:        http://brewpixel.com/plugins/brewpixel-reviews/
 * Description:       Add reviews and/or testimonials.
 * Version:           1.0.0
 * Author:            BrewPixel, Martin Goldie
 * Author URI:        http://brewpixel.com/
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       brewpixel-reviews
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-brewpixel-reviews-activator.php
 */
function activate_brewpixel_reviews() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-reviews-activator.php';
	BrewPixel_Reviews_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-brewpixel-reviews-deactivator.php
 */
function deactivate_brewpixel_reviews() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-reviews-deactivator.php';
	BrewPixel_Reviews_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_brewpixel_reviews' );
register_deactivation_hook( __FILE__, 'deactivate_brewpixel_reviews' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-brewpixel-reviews.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_brewpixel_reviews() {

	$plugin = new BrewPixel_Reviews();
	$plugin->run();

}
run_brewpixel_reviews();

/**
 * Check to make sure the BrewPress plugin has been installed and activated.
 */
function brewpixel_reviews_check_plugin_requirements() {
	if ( false === class_exists( '\BrewPixel\BrewPress\BrewPress' ) ) {
		require_once( ABSPATH . 'wp-admin/includes/plugin.php' );
		deactivate_plugins( plugin_basename( __FILE__ ) );
		$html = '<div class="error">';
		$html .= '<p>';
		$html .= __(
			'There was a problem activating the BrewPixel Reviews plugin.',
			'brewpixel-reviews'
		);
		$html .= '</p>';
		$html .= __(
			'The BrewPixel Reviews plugin requires that the BrewPress plugin be activated. Please try again. Sorry about that.',
			'brewpixel-reviews'
		);
		$html .= '</div><!-- /.updated -->';
		wp_die( wp_kses_post( $html ) );
	}
}
add_action( 'plugins_loaded', 'bp_bespoke_check_plugin_requirements' );
